Data

Struct Data 

pub struct Data { /* private fields */ }
Represents the data attribute of a svg path

Implementations

Source

impl Data

pub fn new() -> Self

a new empty data element

pub fn from_points(points: &[Point]) -> Self

Create the element content from a series of points Note: there must be more than one point for this to do anything.

pub fn move_to(&mut self, p: Point) -> &mut Data

Add a Move To step to this path.

pub fn line_to(&mut self, p: Point) -> &mut Data

Add a line to step to this path

pub fn arc_to<RX, RY, ROT>( &mut self, p: Point, rx: RX, ry: RY, rotation: ROT, large: bool, sweep: bool, ) -> &mut Data
where RX: Display, RY: Display, ROT: Display,

Add an arc to step to this path

pub fn close(&mut self) -> &mut Data

Close the loop of this path.

pub fn build(&self) -> String

Turn this data attribute into a string.

pub fn to_path(&self) -> Element

build a path element using this data attribute