pub struct Data { /* private fields */ }Expand description
Represents the data attribute of a svg path
Implementations
Sourceimpl Data
impl Data
Sourcepub fn from_points(points: &[Point]) -> Self
pub fn from_points(points: &[Point]) -> Self
Create the element content from a series of points Note: there must be more than one point for this to do anything.